==> yt-2.0.0.tar.gz: lib/yt.dart <==
///The YouTube Live Streaming API reference explains how to schedule live broadcasts and video streams
///on YouTube using the YouTube Live Streaming API.
///
///The YouTube Data API lets you incorporate functions normally executed on the
///YouTube website into your own website or application.
library yt;

// export 'package:dio_cache_interceptor/dio_cache_interceptor.dart'
//     show CachePolicy;

export 'src/broadcast.dart';
export 'src/channels.dart';
export 'src/chat.dart';
export 'src/live_stream.dart';
export 'src/chatbot.dart';
export 'src/cmd/youtube_authorize_command.dart';
export 'src/cmd/youtube_broadcast_command.dart';
export 'src/cmd/youtube_channels_command.dart';
export 'src/cmd/youtube_playlists_command.dart';
export 'src/cmd/youtube_chat_command.dart';
export 'src/cmd/youtube_helper_command.dart';
export 'src/cmd/youtube_search_command.dart';
export 'src/cmd/youtube_stream_command.dart';
export 'src/cmd/youtube_thumbnails_command.dart';
export 'src/cmd/youtube_videos_command.dart';
export 'src/cmd/youtube_video_categories_command.dart';
export 'src/model/broadcast/live_broadcast_item.dart';
export 'src/model/broadcast/live_broadcast_response.dart';
export 'src/model/broadcast/status.dart';
export 'src/model/channels/channel_item.dart';
export 'src/model/channels/channel_response.dart';
export 'src/model/chat/live_chat_message.dart';
export 'src/model/chat/live_chat_message_list_response.dart';
export 'src/model/playlist/playlist.dart';
export 'src/model/playlist/playlist_response.dart';
export 'src/model/playlistItem/playlist_item.dart';
export 'src/model/playlistItem/playlist_item_list_response.dart';
export 'src/model/search/search_list_response.dart';
export 'src/model/search/search_result.dart';
export 'src/model/stream/live_tream_item.dart';
export 'src/model/stream/live_stream_list_response.dart';
export 'src/model/thumbnail.dart';
export 'src/model/thumbnail/thumbnail_set_response.dart';
export 'src/model/util/dialog.dart';
export 'src/model/util/jwt_credentials.dart';
export 'src/model/util/keyword.dart';
export 'src/model/util/oauth_credentials.dart';
export 'src/model/util/token.dart';
export 'src/model/video/rating.dart';
export 'src/model/video/report_abuse.dart';
export 'src/model/video/video_category_list_response.dart';
export 'src/model/video/video_get_rating_response.dart';
export 'src/model/video/video_item.dart';
export 'src/model/video/video_list_response.dart';
export 'src/playlist_items.dart';
export 'src/playlists.dart';
export 'src/search.dart';
export 'src/thumbnails.dart';
export 'src/videos.dart';
export 'src/video_categories.dart';
export 'src/yt_base.dart';
export 'util/authorization_exception.dart';
export 'util/emoji_formatter.dart';
export 'util/extras.dart';
export 'util/phrase_match.dart';
export 'util/time_store.dart';
export 'util/token_generator.dart';
export 'util/util.dart';

==> yt-2.0.2.tar.gz: lib/yt.dart <==
///The YouTube Live Streaming API reference explains how to schedule live broadcasts and video streams
///on YouTube using the YouTube Live Streaming API.
///
///The YouTube Data API lets you incorporate functions normally executed on the
///YouTube website into your own website or application.
library yt;

// export 'package:dio_cache_interceptor/dio_cache_interceptor.dart'
//     show CachePolicy;

export 'src/broadcast.dart';
export 'src/channels.dart';
export 'src/chat.dart';
export 'src/live_stream.dart';
export 'src/chatbot.dart';
export 'src/cmd/youtube_authorize_command.dart';
export 'src/cmd/youtube_broadcast_command.dart';
export 'src/cmd/youtube_channels_command.dart';
export 'src/cmd/youtube_playlists_command.dart';
export 'src/cmd/youtube_chat_command.dart';
export 'src/cmd/youtube_helper_command.dart';
export 'src/cmd/youtube_search_command.dart';
export 'src/cmd/youtube_stream_command.dart';
export 'src/cmd/youtube_thumbnails_command.dart';
export 'src/cmd/youtube_videos_command.dart';
export 'src/cmd/youtube_video_categories_command.dart';
export 'src/model/broadcast/live_broadcast_item.dart';
export 'src/model/broadcast/live_broadcast_response.dart';
export 'src/model/broadcast/status.dart';
export 'src/model/channels/channel_item.dart';
export 'src/model/channels/channel_response.dart';
export 'src/model/chat/dialog.dart';
export 'src/model/chat/keyword.dart';
export 'src/model/chat/live_chat_message.dart';
export 'src/model/chat/live_chat_message_list_response.dart';
export 'src/model/playlist/playlist.dart';
export 'src/model/playlist/playlist_response.dart';
export 'src/model/playlistItem/playlist_item.dart';
export 'src/model/playlistItem/playlist_item_list_response.dart';
export 'src/model/search/search_list_response.dart';
export 'src/model/search/search_result.dart';
export 'src/model/stream/live_tream_item.dart';
export 'src/model/stream/live_stream_list_response.dart';
export 'src/model/thumbnail.dart';
export 'src/model/thumbnail/thumbnail_set_response.dart';
export 'src/model/util/jwt_credentials.dart';
export 'src/model/util/oauth_credentials.dart';
export 'src/model/util/token.dart';
export 'src/model/video/rating.dart';
export 'src/model/video/report_abuse.dart';
export 'src/model/video/video_category_list_response.dart';
export 'src/model/video/video_get_rating_response.dart';
export 'src/model/video/video_item.dart';
export 'src/model/video/video_list_response.dart';
export 'src/playlist_items.dart';
export 'src/playlists.dart';
export 'src/search.dart';
export 'src/thumbnails.dart';
export 'src/videos.dart';
export 'src/video_categories.dart';
export 'src/yt_base.dart';
export 'util/authorization_exception.dart';
export 'util/emoji_formatter.dart';
export 'util/extras.dart';
export 'util/phrase_match.dart';
export 'util/time_store.dart';
export 'util/token_generator.dart';
export 'util/util.dart';
